@@ -101,6 +101,7 @@ function_entry ps_functions[] = {
 	PHP_FE(ps_curveto, NULL)
 	PHP_FE(ps_circle, NULL)
 	PHP_FE(ps_arc, NULL)
+	PHP_FE(ps_arcn, NULL)
 	PHP_FE(ps_rect, NULL)
 	PHP_FE(ps_closepath, NULL)
 	PHP_FE(ps_stroke, NULL)
@@ -263,7 +264,7 @@ PHP_MINFO_FUNCTION(ps)
 	php_info_print_table_start();
 	php_info_print_table_row(2, "PS Support", "enabled" );
 	php_info_print_table_row(2, "PSlib Version", tmp );
-	php_info_print_table_row(2, "Revision", "$Revision: 1.26 $" );
+	php_info_print_table_row(2, "Revision", "$Revision: 1.29 $" );
 	php_info_print_table_end();
 
 }
@@ -463,7 +464,7 @@ PHP_FUNCTION(ps_get_value)
 	PSDOC_FROM_ZVAL(ps, &zps);
 
 	if(zmod) {
-		value = (double) PS_get_value(ps, name, (float) Z_DVAL_P(zmod));
+		value = (double) PS_get_value(ps, name, (float) Z_LVAL_P(zmod));
 	} else {
 		value = (double) PS_get_value(ps, name, 0.0);
 	}
@@ -1006,7 +1007,7 @@ PHP_FUNCTION(ps_show_boxed)
 {
 	zval *zps;
 	double x, y, width, height;
-	char *text, *feature, *mode;
+	char *text, *feature = NULL, *mode;
 	int text_len, feature_len, mode_len;
 	int nr;
 	PSDoc *ps;
@@ -1478,6 +1479,7 @@ PHP_FUNCTION(ps_shading_pattern)
 	RETURN_LONG(patternid);
 }
 /* }}} */
+
 /* {{{ proto void ps_add_weblink(int psdoc, double llx, double lly, double urx, double ury, string url)
    Adds link to web resource */
 PHP_FUNCTION(ps_add_weblink)
@@ -1573,7 +1575,7 @@ PHP_FUNCTION(ps_set_border_dash)
 	double black, white;
 	PSDoc *ps;
 
-	if (FAILURE == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rddd", &zps, &black, &white)) {
+	if (FAILURE == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "rdd", &zps, &black, &white)) {
 		return;
 	}
 
